@@ -1,6 +1,6 @@
 package Courriel::Builder;
 {
-  $Courriel::Builder::VERSION = '0.29';
+  $Courriel::Builder::VERSION = '0.31';
 }
 
 use strict;
@@ -36,7 +36,6 @@ BEGIN {
         from
         to
         cc
-        bcc
         header
         plain_body
         html_body
@@ -221,23 +220,6 @@ sub _add_required_headers {
     }
 }
 
-{
-    my $spec = { isa => EmailAddressStr, coerce => 1 };
-
-    sub bcc {
-        my $count = @_ ? @_ : 1;
-        my (@bcc) = pos_validated_list(
-            \@_,
-            ($spec) x $count,
-            MX_PARAMS_VALIDATE_NO_CACHE => 1,
-        );
-
-        @bcc = map { blessed($_) ? $_->format() : $_ } @bcc;
-
-        return { header => [ Bcc => join ', ', @bcc ] };
-    }
-}
-
 {
     my @spec = (
         { isa => NonEmptyStr },
@@ -465,7 +447,7 @@ sub _attachment_disposition {
 
 # ABSTRACT: Build emails with sugar
 
-
+__END__
 
 =pod
 
@@ -475,7 +457,7 @@ Courriel::Builder - Build emails with sugar
 
 =head1 VERSION
 
-version 0.29
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -539,11 +521,6 @@ L<Email::Address> objects.
 This sets the Cc header of the email. It expects a list of string and/or
 L<Email::Address> objects.
 
-=head2 bcc($from)
-
-This sets the Bcc header of the email. It expects a list of string and/or
-L<Email::Address> objects.
-
 =head2 header( $name => $value )
 
 This sets a header's value. You can call it as many times as you want, and you
@@ -685,12 +662,12 @@ This creates an email with this structure:
         html_body(
             $html_text,
             attach(
-                file => 'path/to/image1.jpg',
-                cid  => 'image1',
+                file       => 'path/to/image1.jpg',
+                content_id => 'image1',
             ),
             attach(
-                file => 'path/to/image2.jpg',
-                cid  => 'image2',
+                file       => 'path/to/image2.jpg',
+                content_id => 'image2',
             ),
         ),
     );
@@ -720,6 +697,8 @@ This creates an email with this structure:
         attach( content => \$png_image_content ),
     );
 
+This creates an email with this structure:
+
     multipart/mixed
       |
       |-- multipart/alternative
@@ -734,16 +713,16 @@ This creates an email with this structure:
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Zbigniew Łukasiak <zzbbyy@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2013 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
