@@ -1,6 +1,6 @@
 package Courriel::Header;
 {
-  $Courriel::Header::VERSION = '0.28';
+  $Courriel::Header::VERSION = '0.31';
 }
 
 use strict;
@@ -155,7 +155,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A single header's name and value
 
-
+__END__
 
 =pod
 
@@ -165,7 +165,7 @@ Courriel::Header - A single header's name and value
 
 =head1 VERSION
 
-version 0.28
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -218,16 +218,16 @@ This class does the C<Courriel::Role::Streams> role.
 
 Dave Rolsky <autarch@urth.org>
 
+=head1 CONTRIBUTOR
+
+Zbigniew Łukasiak <zzbbyy@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2013 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
